"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import abc
import collections.abc
import google.protobuf.empty_pb2
import grpc
import grpc.aio
import typing
import yandex.cloud.access.access_pb2
import yandex.cloud.datasphere.v2.project_pb2
import yandex.cloud.datasphere.v2.project_service_pb2
import yandex.cloud.datasphere.v2.restrictions_pb2
import yandex.cloud.operation.operation_pb2

_T = typing.TypeVar("_T")

class _MaybeAsyncIterator(collections.abc.AsyncIterator[_T], collections.abc.Iterator[_T], metaclass=abc.ABCMeta): ...

class _ServicerContext(grpc.ServicerContext, grpc.aio.ServicerContext):  # type: ignore[misc, type-arg]
    ...

class ProjectServiceStub:
    """A set of methods for managing Project resources."""

    def __init__(self, channel: typing.Union[grpc.Channel, grpc.aio.Channel]) -> None: ...
    Create: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.CreateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a project in the specified folder."""

    Update: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.UpdateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified project."""

    Delete: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.DeleteProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified project."""

    Open: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.OpenProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens the specified project."""

    Get: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetProjectRequest,
        yandex.cloud.datasphere.v2.project_pb2.Project,
    ]
    """Returns the specified project."""

    List: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsResponse,
    ]
    """Lists projects for the specified community."""

    GetUnitBalance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceResponse,
    ]
    """Returns the unit balance of the specified project."""

    SetUnitBalance: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.SetUnitBalanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the unit balance of the specified project."""

    Execute: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.ProjectExecutionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes code of the specified notebook using configuration defined in the project settings. If the default project configuration is not specified, `c1.4` is used."""

    GetCellOutputs: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsResponse,
    ]
    """Returns outputs of the specified cell.
    Deprecated
    """

    GetStateVariables: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesResponse,
    ]
    """Returns state variables of the specified notebook.
    Deprecated
    """

    ListAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the project."""

    SetAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the project."""

    UpdateAccessBindings: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the project."""

    AddResource: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.AddResourceToProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds shared resource to project"""

    RemoveResource: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.RemoveResourceFromProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes shared resource from project"""

    GetRestrictionsMeta: grpc.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse,
    ]
    """Get meta information about available restrictions."""

    GetRestrictions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetProjectRestrictionsRequest,
        yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse,
    ]
    """Get current project restrictions."""

    SetRestrictions: grpc.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.SetProjectRestrictionsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set project restrictions."""

class ProjectServiceAsyncStub:
    """A set of methods for managing Project resources."""

    Create: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.CreateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Creates a project in the specified folder."""

    Update: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.UpdateProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates the specified project."""

    Delete: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.DeleteProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Deletes the specified project."""

    Open: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.OpenProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Opens the specified project."""

    Get: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetProjectRequest,
        yandex.cloud.datasphere.v2.project_pb2.Project,
    ]
    """Returns the specified project."""

    List: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsResponse,
    ]
    """Lists projects for the specified community."""

    GetUnitBalance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceResponse,
    ]
    """Returns the unit balance of the specified project."""

    SetUnitBalance: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.SetUnitBalanceRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets the unit balance of the specified project."""

    Execute: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.ProjectExecutionRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Executes code of the specified notebook using configuration defined in the project settings. If the default project configuration is not specified, `c1.4` is used."""

    GetCellOutputs: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsResponse,
    ]
    """Returns outputs of the specified cell.
    Deprecated
    """

    GetStateVariables: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesRequest,
        yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesResponse,
    ]
    """Returns state variables of the specified notebook.
    Deprecated
    """

    ListAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        yandex.cloud.access.access_pb2.ListAccessBindingsResponse,
    ]
    """Lists access bindings for the project."""

    SetAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Sets access bindings for the project."""

    UpdateAccessBindings: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Updates access bindings for the project."""

    AddResource: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.AddResourceToProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Adds shared resource to project"""

    RemoveResource: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.RemoveResourceFromProjectRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Removes shared resource from project"""

    GetRestrictionsMeta: grpc.aio.UnaryUnaryMultiCallable[
        google.protobuf.empty_pb2.Empty,
        yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse,
    ]
    """Get meta information about available restrictions."""

    GetRestrictions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.GetProjectRestrictionsRequest,
        yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse,
    ]
    """Get current project restrictions."""

    SetRestrictions: grpc.aio.UnaryUnaryMultiCallable[
        yandex.cloud.datasphere.v2.project_service_pb2.SetProjectRestrictionsRequest,
        yandex.cloud.operation.operation_pb2.Operation,
    ]
    """Set project restrictions."""

class ProjectServiceServicer(metaclass=abc.ABCMeta):
    """A set of methods for managing Project resources."""

    @abc.abstractmethod
    def Create(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.CreateProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Creates a project in the specified folder."""

    @abc.abstractmethod
    def Update(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.UpdateProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates the specified project."""

    @abc.abstractmethod
    def Delete(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.DeleteProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Deletes the specified project."""

    @abc.abstractmethod
    def Open(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.OpenProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Opens the specified project."""

    @abc.abstractmethod
    def Get(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.GetProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.project_pb2.Project, collections.abc.Awaitable[yandex.cloud.datasphere.v2.project_pb2.Project]]:
        """Returns the specified project."""

    @abc.abstractmethod
    def List(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.project_service_pb2.ListProjectsResponse]]:
        """Lists projects for the specified community."""

    @abc.abstractmethod
    def GetUnitBalance(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.project_service_pb2.GetUnitBalanceResponse]]:
        """Returns the unit balance of the specified project."""

    @abc.abstractmethod
    def SetUnitBalance(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.SetUnitBalanceRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets the unit balance of the specified project."""

    @abc.abstractmethod
    def Execute(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.ProjectExecutionRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Executes code of the specified notebook using configuration defined in the project settings. If the default project configuration is not specified, `c1.4` is used."""

    @abc.abstractmethod
    def GetCellOutputs(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.project_service_pb2.CellOutputsResponse]]:
        """Returns outputs of the specified cell.
        Deprecated
        """

    @abc.abstractmethod
    def GetStateVariables(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.project_service_pb2.GetStateVariablesResponse]]:
        """Returns state variables of the specified notebook.
        Deprecated
        """

    @abc.abstractmethod
    def ListAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.ListAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.access.access_pb2.ListAccessBindingsResponse, collections.abc.Awaitable[yandex.cloud.access.access_pb2.ListAccessBindingsResponse]]:
        """Lists access bindings for the project."""

    @abc.abstractmethod
    def SetAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.SetAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Sets access bindings for the project."""

    @abc.abstractmethod
    def UpdateAccessBindings(
        self,
        request: yandex.cloud.access.access_pb2.UpdateAccessBindingsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Updates access bindings for the project."""

    @abc.abstractmethod
    def AddResource(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.AddResourceToProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Adds shared resource to project"""

    @abc.abstractmethod
    def RemoveResource(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.RemoveResourceFromProjectRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Removes shared resource from project"""

    @abc.abstractmethod
    def GetRestrictionsMeta(
        self,
        request: google.protobuf.empty_pb2.Empty,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.restrictions_pb2.GetRestrictionsMetaResponse]]:
        """Get meta information about available restrictions."""

    @abc.abstractmethod
    def GetRestrictions(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.GetProjectRestrictionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse, collections.abc.Awaitable[yandex.cloud.datasphere.v2.restrictions_pb2.RestrictionsResponse]]:
        """Get current project restrictions."""

    @abc.abstractmethod
    def SetRestrictions(
        self,
        request: yandex.cloud.datasphere.v2.project_service_pb2.SetProjectRestrictionsRequest,
        context: _ServicerContext,
    ) -> typing.Union[yandex.cloud.operation.operation_pb2.Operation, collections.abc.Awaitable[yandex.cloud.operation.operation_pb2.Operation]]:
        """Set project restrictions."""

def add_ProjectServiceServicer_to_server(servicer: ProjectServiceServicer, server: typing.Union[grpc.Server, grpc.aio.Server]) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.timestamp_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class PlacementGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    SPREAD_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    PARTITION_PLACEMENT_STRATEGY_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the placement group. Generated at creation time."""
    folder_id: builtins.str
    """ID of the folder that the placement group belongs to."""
    name: builtins.str
    """Name of the placement group.
    The name is unique within the folder.
    """
    description: builtins.str
    """Description of the placement group. 0-256 characters long."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Creation timestamp."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Placement group labels as `key:value` pairs."""

    @property
    def spread_placement_strategy(self) -> global___SpreadPlacementStrategy:
        """Anti-affinity placement strategy (`spread`). Instances are distributed
        over distinct failure domains.
        """

    @property
    def partition_placement_strategy(self) -> global___PartitionPlacementStrategy: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        spread_placement_strategy: global___SpreadPlacementStrategy | None = ...,
        partition_placement_strategy: global___PartitionPlacementStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "partition_placement_strategy", b"partition_placement_strategy", "placement_strategy", b"placement_strategy", "spread_placement_strategy", b"spread_placement_strategy"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["placement_strategy", b"placement_strategy"]) -> typing.Literal["spread_placement_strategy", "partition_placement_strategy"] | None: ...

global___PlacementGroup = PlacementGroup

@typing.final
class SpreadPlacementStrategy(google.protobuf.message.Message):
    """This is an empty structure that must be passed to explicitly
    specify the required placement strategy.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SpreadPlacementStrategy = SpreadPlacementStrategy

@typing.final
class PartitionPlacementStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PARTITIONS_FIELD_NUMBER: builtins.int
    partitions: builtins.int
    def __init__(
        self,
        *,
        partitions: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["partitions", b"partitions"]) -> None: ...

global___PartitionPlacementStrategy = PartitionPlacementStrategy



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/iam/v1/workload/federated_credential_service.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from yandex.cloud.api import operation_pb2 as yandex_dot_cloud_dot_api_dot_operation__pb2
from yandex.cloud.iam.v1.workload import federated_credential_pb2 as yandex_dot_cloud_dot_iam_dot_v1_dot_workload_dot_federated__credential__pb2
from yandex.cloud.operation import operation_pb2 as yandex_dot_cloud_dot_operation_dot_operation__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n?yandex/cloud/iam/v1/workload/federated_credential_service.proto\x12\x1cyandex.cloud.iam.v1.workload\x1a\x1cgoogle/api/annotations.proto\x1a yandex/cloud/api/operation.proto\x1a\x37yandex/cloud/iam/v1/workload/federated_credential.proto\x1a&yandex/cloud/operation/operation.proto\x1a\x1dyandex/cloud/validation.proto\"N\n\x1dGetFederatedCredentialRequest\x12-\n\x17\x66\x65\x64\x65rated_credential_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"\x8a\x01\n\x1fListFederatedCredentialsRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12\x1d\n\tpage_size\x18\x02 \x01(\x03\x42\n\xfa\xc7\x31\x06\x30-1000\x12\x1e\n\npage_token\x18\x03 \x01(\tB\n\x8a\xc8\x31\x06<=2000\"\x8d\x01\n ListFederatedCredentialsResponse\x12P\n\x15\x66\x65\x64\x65rated_credentials\x18\x01 \x03(\x0b\x32\x31.yandex.cloud.iam.v1.workload.FederatedCredential\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9c\x01\n CreateFederatedCredentialRequest\x12(\n\x12service_account_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12#\n\rfederation_id\x18\x02 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\x12)\n\x13\x65xternal_subject_id\x18\x03 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n!CreateFederatedCredentialMetadata\x12\x1f\n\x17\x66\x65\x64\x65rated_credential_id\x18\x01 \x01(\t\"Q\n DeleteFederatedCredentialRequest\x12-\n\x17\x66\x65\x64\x65rated_credential_id\x18\x01 \x01(\tB\x0c\xe8\xc7\x31\x01\x8a\xc8\x31\x04<=50\"D\n!DeleteFederatedCredentialMetadata\x12\x1f\n\x17\x66\x65\x64\x65rated_credential_id\x18\x01 \x01(\t2\xe6\x06\n\x1a\x46\x65\x64\x65ratedCredentialService\x12\xbe\x01\n\x03Get\x12;.yandex.cloud.iam.v1.workload.GetFederatedCredentialRequest\x1a\x31.yandex.cloud.iam.v1.workload.FederatedCredential\"G\x82\xd3\xe4\x93\x02\x41\x12?/iam/v1/workload/federatedCredentials/{federated_credential_id}\x12\xb4\x01\n\x04List\x12=.yandex.cloud.iam.v1.workload.ListFederatedCredentialsRequest\x1a>.yandex.cloud.iam.v1.workload.ListFederatedCredentialsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/iam/v1/workload/federatedCredentials\x12\xd9\x01\n\x06\x43reate\x12>.yandex.cloud.iam.v1.workload.CreateFederatedCredentialRequest\x1a!.yandex.cloud.operation.Operation\"l\xb2\xd2*8\n!CreateFederatedCredentialMetadata\x12\x13\x46\x65\x64\x65ratedCredential\x82\xd3\xe4\x93\x02*\"%/iam/v1/workload/federatedCredentials:\x01*\x12\xf3\x01\n\x06\x44\x65lete\x12>.yandex.cloud.iam.v1.workload.DeleteFederatedCredentialRequest\x1a!.yandex.cloud.operation.Operation\"\x85\x01\xb2\xd2*:\n!DeleteFederatedCredentialMetadata\x12\x15google.protobuf.Empty\x82\xd3\xe4\x93\x02\x41*?/iam/v1/workload/federatedCredentials/{federated_credential_id}Bm\n yandex.cloud.api.iam.v1.workloadZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload;workloadb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.iam.v1.workload.federated_credential_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n yandex.cloud.api.iam.v1.workloadZIgithub.com/yandex-cloud/go-genproto/yandex/cloud/iam/v1/workload;workload'
  _GETFEDERATEDCREDENTIALREQUEST.fields_by_name['federated_credential_id']._options = None
  _GETFEDERATEDCREDENTIALREQUEST.fields_by_name['federated_credential_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['service_account_id']._options = None
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['page_size']._options = None
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['page_size']._serialized_options = b'\372\3071\0060-1000'
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['page_token']._options = None
  _LISTFEDERATEDCREDENTIALSREQUEST.fields_by_name['page_token']._serialized_options = b'\212\3101\006<=2000'
  _CREATEFEDERATEDCREDENTIALREQUEST.fields_by_name['service_account_id']._options = None
  _CREATEFEDERATEDCREDENTIALREQUEST.fields_by_name['service_account_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFEDERATEDCREDENTIALREQUEST.fields_by_name['federation_id']._options = None
  _CREATEFEDERATEDCREDENTIALREQUEST.fields_by_name['federation_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _CREATEFEDERATEDCREDENTIALREQUEST.fields_by_name['external_subject_id']._options = None
  _CREATEFEDERATEDCREDENTIALREQUEST.fields_by_name['external_subject_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _DELETEFEDERATEDCREDENTIALREQUEST.fields_by_name['federated_credential_id']._options = None
  _DELETEFEDERATEDCREDENTIALREQUEST.fields_by_name['federated_credential_id']._serialized_options = b'\350\3071\001\212\3101\004<=50'
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['Get']._options = None
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002A\022?/iam/v1/workload/federatedCredentials/{federated_credential_id}'
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['List']._options = None
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['List']._serialized_options = b'\202\323\344\223\002\'\022%/iam/v1/workload/federatedCredentials'
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['Create']._options = None
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['Create']._serialized_options = b'\262\322*8\n!CreateFederatedCredentialMetadata\022\023FederatedCredential\202\323\344\223\002*\"%/iam/v1/workload/federatedCredentials:\001*'
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['Delete']._options = None
  _FEDERATEDCREDENTIALSERVICE.methods_by_name['Delete']._serialized_options = b'\262\322*:\n!DeleteFederatedCredentialMetadata\022\025google.protobuf.Empty\202\323\344\223\002A*?/iam/v1/workload/federatedCredentials/{federated_credential_id}'
  _globals['_GETFEDERATEDCREDENTIALREQUEST']._serialized_start=289
  _globals['_GETFEDERATEDCREDENTIALREQUEST']._serialized_end=367
  _globals['_LISTFEDERATEDCREDENTIALSREQUEST']._serialized_start=370
  _globals['_LISTFEDERATEDCREDENTIALSREQUEST']._serialized_end=508
  _globals['_LISTFEDERATEDCREDENTIALSRESPONSE']._serialized_start=511
  _globals['_LISTFEDERATEDCREDENTIALSRESPONSE']._serialized_end=652
  _globals['_CREATEFEDERATEDCREDENTIALREQUEST']._serialized_start=655
  _globals['_CREATEFEDERATEDCREDENTIALREQUEST']._serialized_end=811
  _globals['_CREATEFEDERATEDCREDENTIALMETADATA']._serialized_start=813
  _globals['_CREATEFEDERATEDCREDENTIALMETADATA']._serialized_end=881
  _globals['_DELETEFEDERATEDCREDENTIALREQUEST']._serialized_start=883
  _globals['_DELETEFEDERATEDCREDENTIALREQUEST']._serialized_end=964
  _globals['_DELETEFEDERATEDCREDENTIALMETADATA']._serialized_start=966
  _globals['_DELETEFEDERATEDCREDENTIALMETADATA']._serialized_end=1034
  _globals['_FEDERATEDCREDENTIALSERVICE']._serialized_start=1037
  _globals['_FEDERATEDCREDENTIALSERVICE']._serialized_end=1907
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetFolderBudgetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to get a budget for."""
    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id"]) -> None: ...

global___GetFolderBudgetRequest = GetFolderBudgetRequest

@typing.final
class GetFolderBudgetResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    UNIT_BALANCE_FIELD_NUMBER: builtins.int
    MAX_UNITS_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_UNITS_PER_EXECUTION_FIELD_NUMBER: builtins.int
    @property
    def unit_balance(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units available in the folder."""

    @property
    def max_units_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units that can be spent per hour."""

    @property
    def max_units_per_execution(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units that can be spent on one execution."""

    def __init__(
        self,
        *,
        unit_balance: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_units_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_units_per_execution: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour", "unit_balance", b"unit_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour", "unit_balance", b"unit_balance"]) -> None: ...

global___GetFolderBudgetResponse = GetFolderBudgetResponse

@typing.final
class SetFolderBudgetRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FOLDER_ID_FIELD_NUMBER: builtins.int
    SET_MASK_FIELD_NUMBER: builtins.int
    UNIT_BALANCE_FIELD_NUMBER: builtins.int
    MAX_UNITS_PER_HOUR_FIELD_NUMBER: builtins.int
    MAX_UNITS_PER_EXECUTION_FIELD_NUMBER: builtins.int
    folder_id: builtins.str
    """ID of the folder to set a budget for."""
    @property
    def set_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which fields of the budget are going to be set."""

    @property
    def unit_balance(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units available in the folder."""

    @property
    def max_units_per_hour(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units that can be spent per hour."""

    @property
    def max_units_per_execution(self) -> google.protobuf.wrappers_pb2.Int64Value:
        """The number of units that can be spent on one execution."""

    def __init__(
        self,
        *,
        folder_id: builtins.str = ...,
        set_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        unit_balance: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_units_per_hour: google.protobuf.wrappers_pb2.Int64Value | None = ...,
        max_units_per_execution: google.protobuf.wrappers_pb2.Int64Value | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour", "set_mask", b"set_mask", "unit_balance", b"unit_balance"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["folder_id", b"folder_id", "max_units_per_execution", b"max_units_per_execution", "max_units_per_hour", b"max_units_per_hour", "set_mask", b"set_mask", "unit_balance", b"unit_balance"]) -> None: ...

global___SetFolderBudgetRequest = SetFolderBudgetRequest



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.dataproc.manager.v1.job_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ListJobsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    FILTER_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the cluster to list Data Proc jobs of."""
    page_size: builtins.int
    """The maximum number of results per page that should be returned. If the number of available
    results is larger than `page_size`, the service returns a `next_page_token` that can be used
    to get the next page of results in subsequent ListJobs requests.
    Acceptable values are 0 to 1000, inclusive. Default value: 100.
    """
    page_token: builtins.str
    """Page token. Set `page_token` to the `next_page_token` returned by a previous ListJobs
    request to get the next page of results.
    """
    filter: builtins.str
    """String that describes a display filter."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
        filter: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "filter", b"filter", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListJobsRequest = ListJobsRequest

@typing.final
class ListJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListJobs requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListClusters request. Subsequent ListClusters
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dataproc.manager.v1.job_pb2.Job]:
        """Requested list of Data Proc jobs."""

    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[yandex.cloud.dataproc.manager.v1.job_pb2.Job] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["jobs", b"jobs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListJobsResponse = ListJobsResponse

@typing.final
class UpdateJobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    APPLICATION_INFO_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the Data Proc cluster."""
    job_id: builtins.str
    """Required. ID of the Data Proc job to update."""
    status: yandex.cloud.dataproc.manager.v1.job_pb2.Job.Status.ValueType
    """Required. New status of the job."""
    @property
    def application_info(self) -> yandex.cloud.dataproc.manager.v1.job_pb2.ApplicationInfo:
        """Attributes of YARN application."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
        status: yandex.cloud.dataproc.manager.v1.job_pb2.Job.Status.ValueType = ...,
        application_info: yandex.cloud.dataproc.manager.v1.job_pb2.ApplicationInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["application_info", b"application_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["application_info", b"application_info", "cluster_id", b"cluster_id", "job_id", b"job_id", "status", b"status"]) -> None: ...

global___UpdateJobStatusRequest = UpdateJobStatusRequest

@typing.final
class UpdateJobStatusResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___UpdateJobStatusResponse = UpdateJobStatusResponse

@typing.final
class ListSupportJobsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    JOBS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for ListJobs requests,
    if the number of results is larger than `page_size` specified in the request.
    To get the next page, specify the value of `next_page_token` as a value for
    the `page_token` parameter in the next ListClusters request. Subsequent ListClusters
    requests will have their own `next_page_token` to continue paging through the results.
    """
    @property
    def jobs(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.dataproc.manager.v1.job_pb2.SupportJob]:
        """Requested list of Data Proc jobs."""

    def __init__(
        self,
        *,
        jobs: collections.abc.Iterable[yandex.cloud.dataproc.manager.v1.job_pb2.SupportJob] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["jobs", b"jobs", "next_page_token", b"next_page_token"]) -> None: ...

global___ListSupportJobsResponse = ListSupportJobsResponse

@typing.final
class UpdateSupportJobStatusRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """Required. ID of the Data Proc cluster."""
    job_id: builtins.str
    """Required. ID of the Data Proc job to update."""
    status: yandex.cloud.dataproc.manager.v1.job_pb2.SupportJob.Status.ValueType
    """Required. New status of the job."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
        status: yandex.cloud.dataproc.manager.v1.job_pb2.SupportJob.Status.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id", "status", b"status"]) -> None: ...

global___UpdateSupportJobStatusRequest = UpdateSupportJobStatusRequest

@typing.final
class SaveSupportJobLogRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    JOB_ID_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster."""
    job_id: builtins.str
    """ID of the support job."""
    output: builtins.str
    """Job output."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        job_id: builtins.str = ...,
        output: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "job_id", b"job_id", "output", b"output"]) -> None: ...

global___SaveSupportJobLogRequest = SaveSupportJobLogRequest

@typing.final
class SaveSupportJobLogResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___SaveSupportJobLogResponse = SaveSupportJobLogResponse



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class HistoryEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[HistoryEntry._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: HistoryEntry._Status.ValueType  # 0
        SCHEDULED: HistoryEntry._Status.ValueType  # 1
        """Step execution is being scheduled."""
        STARTED: HistoryEntry._Status.ValueType  # 2
        """Step execution is started."""
        COMPLETED: HistoryEntry._Status.ValueType  # 3
        """Step execution is completed."""
        FAILED: HistoryEntry._Status.ValueType  # 4
        """Step execution is failed."""
        CANCEL_REQUESTED: HistoryEntry._Status.ValueType  # 5
        """Step execution is requested to be cancelled."""
        CANCELLED: HistoryEntry._Status.ValueType  # 6
        """Step execution is canceled."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: HistoryEntry.Status.ValueType  # 0
    SCHEDULED: HistoryEntry.Status.ValueType  # 1
    """Step execution is being scheduled."""
    STARTED: HistoryEntry.Status.ValueType  # 2
    """Step execution is started."""
    COMPLETED: HistoryEntry.Status.ValueType  # 3
    """Step execution is completed."""
    FAILED: HistoryEntry.Status.ValueType  # 4
    """Step execution is failed."""
    CANCEL_REQUESTED: HistoryEntry.Status.ValueType  # 5
    """Step execution is requested to be cancelled."""
    CANCELLED: HistoryEntry.Status.ValueType  # 6
    """Step execution is canceled."""

    ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    STARTED_AT_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    INPUT_FIELD_NUMBER: builtins.int
    OUTPUT_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the Workflow step."""
    title: builtins.str
    """Title of the Workflow step."""
    description: builtins.str
    """Description of the Workflow step."""
    status: global___HistoryEntry.Status.ValueType
    """Status of the Workflow step."""
    type: builtins.str
    """Type of the Workflow step (for example, FunctionCall or HttpCall)."""
    @property
    def started_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Start timestamp for the Workflow step."""

    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Duration of the Workflow step."""

    @property
    def input(self) -> global___HistoryEntryInput:
        """Input data for the Workflow step."""

    @property
    def output(self) -> global___HistoryEntryOutput:
        """Result of the Workflow step."""

    @property
    def error(self) -> global___HistoryEntryError:
        """Error details, in case Workflow step failed."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        started_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        input: global___HistoryEntryInput | None = ...,
        output: global___HistoryEntryOutput | None = ...,
        error: global___HistoryEntryError | None = ...,
        status: global___HistoryEntry.Status.ValueType = ...,
        type: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["duration", b"duration", "error", b"error", "input", b"input", "output", b"output", "started_at", b"started_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["description", b"description", "duration", b"duration", "error", b"error", "id", b"id", "input", b"input", "output", b"output", "started_at", b"started_at", "status", b"status", "title", b"title", "type", b"type"]) -> None: ...

global___HistoryEntry = HistoryEntry

@typing.final
class HistoryEntryInput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INPUT_JSON_FIELD_NUMBER: builtins.int
    input_json: builtins.str
    """JSON input data for the Workflow step."""
    def __init__(
        self,
        *,
        input_json: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["input", b"input", "input_json", b"input_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["input", b"input", "input_json", b"input_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["input", b"input"]) -> typing.Literal["input_json"] | None: ...

global___HistoryEntryInput = HistoryEntryInput

@typing.final
class HistoryEntryOutput(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OUTPUT_JSON_FIELD_NUMBER: builtins.int
    output_json: builtins.str
    """JSON result for the Workflow step."""
    def __init__(
        self,
        *,
        output_json: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["output", b"output", "output_json", b"output_json"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["output", b"output", "output_json", b"output_json"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["output", b"output"]) -> typing.Literal["output_json"] | None: ...

global___HistoryEntryOutput = HistoryEntryOutput

@typing.final
class HistoryEntryError(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_CODE_FIELD_NUMBER: builtins.int
    message: builtins.str
    """Error message of the Workflow step."""
    error_code: builtins.str
    """Error code of the Workflow step."""
    def __init__(
        self,
        *,
        message: builtins.str = ...,
        error_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["error_code", b"error_code", "message", b"message"]) -> None: ...

global___HistoryEntryError = HistoryEntryError



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/containerregistry/v1/registry.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/containerregistry/v1/registry.proto\x12!yandex.cloud.containerregistry.v1\x1a\x1fgoogle/protobuf/timestamp.proto\"\xed\x02\n\x08Registry\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x42\n\x06status\x18\x04 \x01(\x0e\x32\x32.yandex.cloud.containerregistry.v1.Registry.Status\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12G\n\x06labels\x18\x06 \x03(\x0b\x32\x37.yandex.cloud.containerregistry.v1.Registry.LabelsEntry\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"H\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x42\x80\x01\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistryb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.containerregistry.v1.registry_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%yandex.cloud.api.containerregistry.v1ZWgithub.com/yandex-cloud/go-genproto/yandex/cloud/containerregistry/v1;containerregistry'
  _REGISTRY_LABELSENTRY._options = None
  _REGISTRY_LABELSENTRY._serialized_options = b'8\001'
  _globals['_REGISTRY']._serialized_start=121
  _globals['_REGISTRY']._serialized_end=486
  _globals['_REGISTRY_LABELSENTRY']._serialized_start=367
  _globals['_REGISTRY_LABELSENTRY']._serialized_end=412
  _globals['_REGISTRY_STATUS']._serialized_start=414
  _globals['_REGISTRY_STATUS']._serialized_end=486
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class StaticChunkingStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_CHUNK_SIZE_TOKENS_FIELD_NUMBER: builtins.int
    CHUNK_OVERLAP_TOKENS_FIELD_NUMBER: builtins.int
    max_chunk_size_tokens: builtins.int
    chunk_overlap_tokens: builtins.int
    def __init__(
        self,
        *,
        max_chunk_size_tokens: builtins.int = ...,
        chunk_overlap_tokens: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["chunk_overlap_tokens", b"chunk_overlap_tokens", "max_chunk_size_tokens", b"max_chunk_size_tokens"]) -> None: ...

global___StaticChunkingStrategy = StaticChunkingStrategy

@typing.final
class ChunkingStrategy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATIC_STRATEGY_FIELD_NUMBER: builtins.int
    @property
    def static_strategy(self) -> global___StaticChunkingStrategy: ...
    def __init__(
        self,
        *,
        static_strategy: global___StaticChunkingStrategy | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["Strategy", b"Strategy", "static_strategy", b"static_strategy"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["Strategy", b"Strategy", "static_strategy", b"static_strategy"]) -> None: ...
    def WhichOneof(self, oneof_group: typing.Literal["Strategy", b"Strategy"]) -> typing.Literal["static_strategy"] | None: ...

global___ChunkingStrategy = ChunkingStrategy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.field_mask_pb2
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.mdb.clickhouse.v1.user_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class GetUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the ClickHouse User resource to return.
    To get the name of the user, use a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GetUserRequest = GetUserRequest

@typing.final
class ListUsersRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the cluster to list ClickHouse users in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    page_size: builtins.int
    """The maximum number of results per page to return. If the number of available
    results is larger than [page_size], the service returns a [ListUsersResponse.next_page_token]
    that can be used to get the next page of results in subsequent list requests.
    """
    page_token: builtins.str
    """Page token.  To get the next page of results, set [page_token] to the [ListUsersResponse.next_page_token]
    returned by the previous list request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        page_size: builtins.int = ...,
        page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "page_size", b"page_size", "page_token", b"page_token"]) -> None: ...

global___ListUsersRequest = ListUsersRequest

@typing.final
class ListUsersResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USERS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: builtins.str
    """This token allows you to get the next page of results for list requests. If the number of results
    is larger than [ListUsersRequest.page_size], use the [next_page_token] as the value
    for the [ListUsersRequest.page_token] parameter in the next list request. Each subsequent
    list request will have its own [next_page_token] to continue paging through the results.
    """
    @property
    def users(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.user_pb2.User]:
        """List of ClickHouse User resources."""

    def __init__(
        self,
        *,
        users: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.user_pb2.User] | None = ...,
        next_page_token: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["next_page_token", b"next_page_token", "users", b"users"]) -> None: ...

global___ListUsersResponse = ListUsersResponse

@typing.final
class CreateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_SPEC_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster to create a user in.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    @property
    def user_spec(self) -> yandex.cloud.mdb.clickhouse.v1.user_pb2.UserSpec:
        """Properties of the user to be created."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_spec: yandex.cloud.mdb.clickhouse.v1.user_pb2.UserSpec | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["user_spec", b"user_spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_spec", b"user_spec"]) -> None: ...

global___CreateUserRequest = CreateUserRequest

@typing.final
class CreateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user is being created in."""
    user_name: builtins.str
    """Name of the user that is being created."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___CreateUserMetadata = CreateUserMetadata

@typing.final
class UpdateUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    UPDATE_MASK_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    PERMISSIONS_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    QUOTAS_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to be updated.
    To get the name of the user, use a [UserService.List] request.
    """
    password: builtins.str
    """New password for the user."""
    @property
    def update_mask(self) -> google.protobuf.field_mask_pb2.FieldMask:
        """Field mask that specifies which attributes of the ClickHouse user should be updated."""

    @property
    def permissions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.user_pb2.Permission]:
        """New set of permissions for the user."""

    @property
    def settings(self) -> yandex.cloud.mdb.clickhouse.v1.user_pb2.UserSettings: ...
    @property
    def quotas(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.mdb.clickhouse.v1.user_pb2.UserQuota]: ...
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        update_mask: google.protobuf.field_mask_pb2.FieldMask | None = ...,
        password: builtins.str = ...,
        permissions: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.user_pb2.Permission] | None = ...,
        settings: yandex.cloud.mdb.clickhouse.v1.user_pb2.UserSettings | None = ...,
        quotas: collections.abc.Iterable[yandex.cloud.mdb.clickhouse.v1.user_pb2.UserQuota] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["settings", b"settings", "update_mask", b"update_mask"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "password", b"password", "permissions", b"permissions", "quotas", b"quotas", "settings", b"settings", "update_mask", b"update_mask", "user_name", b"user_name"]) -> None: ...

global___UpdateUserRequest = UpdateUserRequest

@typing.final
class UpdateUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being updated."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___UpdateUserMetadata = UpdateUserMetadata

@typing.final
class DeleteUserRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to delete.
    To get the name of the user, use a [UserService.List] request.
    """
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserRequest = DeleteUserRequest

@typing.final
class DeleteUserMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being deleted."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___DeleteUserMetadata = DeleteUserMetadata

@typing.final
class GrantUserPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    PERMISSION_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to grant the permission to.
    To get the name of the user, use a [UserService.List] request.
    """
    @property
    def permission(self) -> yandex.cloud.mdb.clickhouse.v1.user_pb2.Permission:
        """Permission that should be granted to the specified user."""

    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        permission: yandex.cloud.mdb.clickhouse.v1.user_pb2.Permission | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["permission", b"permission"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "permission", b"permission", "user_name", b"user_name"]) -> None: ...

global___GrantUserPermissionRequest = GrantUserPermissionRequest

@typing.final
class GrantUserPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user that is being granted a permission."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___GrantUserPermissionMetadata = GrantUserPermissionMetadata

@typing.final
class RevokeUserPermissionRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    DATABASE_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to.
    To get the cluster ID, use a [ClusterService.List] request.
    """
    user_name: builtins.str
    """Name of the user to revoke a permission from.
    To get the name of the user, use a [UserService.List] request.
    """
    database_name: builtins.str
    """Name of the database that the user should lose access to."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
        database_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "database_name", b"database_name", "user_name", b"user_name"]) -> None: ...

global___RevokeUserPermissionRequest = RevokeUserPermissionRequest

@typing.final
class RevokeUserPermissionMetadata(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_ID_FIELD_NUMBER: builtins.int
    USER_NAME_FIELD_NUMBER: builtins.int
    cluster_id: builtins.str
    """ID of the ClickHouse cluster the user belongs to."""
    user_name: builtins.str
    """Name of the user whose permission is being revoked."""
    def __init__(
        self,
        *,
        cluster_id: builtins.str = ...,
        user_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["cluster_id", b"cluster_id", "user_name", b"user_name"]) -> None: ...

global___RevokeUserPermissionMetadata = RevokeUserPermissionMetadata



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2
import yandex.cloud.speechsense.v1.analysis.statistics_common_pb2

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class ConversationStatistics(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONVERSATION_BOUNDARIES_FIELD_NUMBER: builtins.int
    SPEAKER_STATISTICS_FIELD_NUMBER: builtins.int
    @property
    def conversation_boundaries(self) -> yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries:
        """Audio segment boundaries"""

    @property
    def speaker_statistics(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2.SpeakerStatistics]:
        """Average statistics for each speaker"""

    def __init__(
        self,
        *,
        conversation_boundaries: yandex.cloud.speechsense.v1.analysis.statistics_common_pb2.AudioSegmentBoundaries | None = ...,
        speaker_statistics: collections.abc.Iterable[yandex.cloud.speechsense.v1.analysis.speaker_statistics_pb2.SpeakerStatistics] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["conversation_boundaries", b"conversation_boundaries"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["conversation_boundaries", b"conversation_boundaries", "speaker_statistics", b"speaker_statistics"]) -> None: ...

global___ConversationStatistics = ConversationStatistics



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/serverless/apigateway/v1/apigateway.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from yandex.cloud.logging.v1 import log_entry_pb2 as yandex_dot_cloud_dot_logging_dot_v1_dot_log__entry__pb2
from yandex.cloud import validation_pb2 as yandex_dot_cloud_dot_validation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n6yandex/cloud/serverless/apigateway/v1/apigateway.proto\x12%yandex.cloud.serverless.apigateway.v1\x1a\x1egoogle/protobuf/duration.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\'yandex/cloud/logging/v1/log_entry.proto\x1a\x1dyandex/cloud/validation.proto\"\xf7\x07\n\nApiGateway\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tfolder_id\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12M\n\x06labels\x18\x07 \x03(\x0b\x32=.yandex.cloud.serverless.apigateway.v1.ApiGateway.LabelsEntry\x12H\n\x06status\x18\x08 \x01(\x0e\x32\x38.yandex.cloud.serverless.apigateway.v1.ApiGateway.Status\x12\x0e\n\x06\x64omain\x18\t \x01(\t\x12\x14\n\x0clog_group_id\x18\n \x01(\t\x12O\n\x10\x61ttached_domains\x18\x0b \x03(\x0b\x32\x35.yandex.cloud.serverless.apigateway.v1.AttachedDomain\x12I\n\x0c\x63onnectivity\x18\x0c \x01(\x0b\x32\x33.yandex.cloud.serverless.apigateway.v1.Connectivity\x12\x46\n\x0blog_options\x18\r \x01(\x0b\x32\x31.yandex.cloud.serverless.apigateway.v1.LogOptions\x12S\n\tvariables\x18\x0e \x03(\x0b\x32@.yandex.cloud.serverless.apigateway.v1.ApiGateway.VariablesEntry\x12=\n\x06\x63\x61nary\x18\x0f \x01(\x0b\x32-.yandex.cloud.serverless.apigateway.v1.Canary\x12@\n\x11\x65xecution_timeout\x18\x10 \x01(\x0b\x32\x19.google.protobuf.DurationB\n\xfa\xc7\x31\x06<=600s\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x66\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.serverless.apigateway.v1.VariableInput:\x02\x38\x01\"a\n\x06Status\x12\x16\n\x12STATUS_UNSPECIFIED\x10\x00\x12\x0c\n\x08\x43REATING\x10\x01\x12\n\n\x06\x41\x43TIVE\x10\x02\x12\x0c\n\x08\x44\x45LETING\x10\x03\x12\t\n\x05\x45RROR\x10\x04\x12\x0c\n\x08UPDATING\x10\x05J\x04\x08\x06\x10\x07\"b\n\x0e\x41ttachedDomain\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x16\n\x0e\x63\x65rtificate_id\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x0e\n\x06\x64omain\x18\x05 \x01(\tJ\x04\x08\x04\x10\x05\"5\n\x0c\x43onnectivity\x12\x12\n\nnetwork_id\x18\x01 \x01(\t\x12\x11\n\tsubnet_id\x18\x02 \x03(\t\"\x96\x01\n\nLogOptions\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x16\n\x0clog_group_id\x18\x02 \x01(\tH\x00\x12\x13\n\tfolder_id\x18\x03 \x01(\tH\x00\x12:\n\tmin_level\x18\x04 \x01(\x0e\x32\'.yandex.cloud.logging.v1.LogLevel.LevelB\r\n\x0b\x64\x65stination\"\xe3\x01\n\x06\x43\x61nary\x12\x18\n\x06weight\x18\x01 \x01(\x03\x42\x08\xfa\xc7\x31\x04\x30-99\x12W\n\tvariables\x18\x02 \x03(\x0b\x32<.yandex.cloud.serverless.apigateway.v1.Canary.VariablesEntryB\x06\x82\xc8\x31\x02>0\x1a\x66\n\x0eVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x43\n\x05value\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.serverless.apigateway.v1.VariableInput:\x02\x38\x01\"|\n\rVariableInput\x12\x16\n\x0cstring_value\x18\x01 \x01(\tH\x00\x12\x13\n\tint_value\x18\x02 \x01(\x03H\x00\x12\x16\n\x0c\x64ouble_value\x18\x03 \x01(\x01H\x00\x12\x14\n\nbool_value\x18\x04 \x01(\x08H\x00\x42\x10\n\x0evariable_valueB\x81\x01\n)yandex.cloud.api.serverless.apigateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/v1;apigatewayb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.serverless.apigateway.v1.apigateway_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)yandex.cloud.api.serverless.apigateway.v1ZTgithub.com/yandex-cloud/go-genproto/yandex/cloud/serverless/apigateway/v1;apigateway'
  _APIGATEWAY_LABELSENTRY._options = None
  _APIGATEWAY_LABELSENTRY._serialized_options = b'8\001'
  _APIGATEWAY_VARIABLESENTRY._options = None
  _APIGATEWAY_VARIABLESENTRY._serialized_options = b'8\001'
  _APIGATEWAY.fields_by_name['execution_timeout']._options = None
  _APIGATEWAY.fields_by_name['execution_timeout']._serialized_options = b'\372\3071\006<=600s'
  _CANARY_VARIABLESENTRY._options = None
  _CANARY_VARIABLESENTRY._serialized_options = b'8\001'
  _CANARY.fields_by_name['weight']._options = None
  _CANARY.fields_by_name['weight']._serialized_options = b'\372\3071\0040-99'
  _CANARY.fields_by_name['variables']._options = None
  _CANARY.fields_by_name['variables']._serialized_options = b'\202\3101\002>0'
  _globals['_APIGATEWAY']._serialized_start=235
  _globals['_APIGATEWAY']._serialized_end=1250
  _globals['_APIGATEWAY_LABELSENTRY']._serialized_start=996
  _globals['_APIGATEWAY_LABELSENTRY']._serialized_end=1041
  _globals['_APIGATEWAY_VARIABLESENTRY']._serialized_start=1043
  _globals['_APIGATEWAY_VARIABLESENTRY']._serialized_end=1145
  _globals['_APIGATEWAY_STATUS']._serialized_start=1147
  _globals['_APIGATEWAY_STATUS']._serialized_end=1244
  _globals['_ATTACHEDDOMAIN']._serialized_start=1252
  _globals['_ATTACHEDDOMAIN']._serialized_end=1350
  _globals['_CONNECTIVITY']._serialized_start=1352
  _globals['_CONNECTIVITY']._serialized_end=1405
  _globals['_LOGOPTIONS']._serialized_start=1408
  _globals['_LOGOPTIONS']._serialized_end=1558
  _globals['_CANARY']._serialized_start=1561
  _globals['_CANARY']._serialized_end=1788
  _globals['_CANARY_VARIABLESENTRY']._serialized_start=1043
  _globals['_CANARY_VARIABLESENTRY']._serialized_end=1145
  _globals['_VARIABLEINPUT']._serialized_start=1790
  _globals['_VARIABLEINPUT']._serialized_end=1914
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _SymmetricAlgorithm:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _SymmetricAlgorithmEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_SymmetricAlgorithm.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SYMMETRIC_ALGORITHM_UNSPECIFIED: _SymmetricAlgorithm.ValueType  # 0
    AES_128: _SymmetricAlgorithm.ValueType  # 1
    """AES algorithm with 128-bit keys."""
    AES_192: _SymmetricAlgorithm.ValueType  # 2
    """AES algorithm with 192-bit keys."""
    AES_256: _SymmetricAlgorithm.ValueType  # 3
    """AES algorithm with 256-bit keys."""
    AES_256_HSM: _SymmetricAlgorithm.ValueType  # 4
    """AES algorithm with 256-bit keys hosted by HSM"""

class SymmetricAlgorithm(_SymmetricAlgorithm, metaclass=_SymmetricAlgorithmEnumTypeWrapper):
    """Supported symmetric encryption algorithms."""

SYMMETRIC_ALGORITHM_UNSPECIFIED: SymmetricAlgorithm.ValueType  # 0
AES_128: SymmetricAlgorithm.ValueType  # 1
"""AES algorithm with 128-bit keys."""
AES_192: SymmetricAlgorithm.ValueType  # 2
"""AES algorithm with 192-bit keys."""
AES_256: SymmetricAlgorithm.ValueType  # 3
"""AES algorithm with 256-bit keys."""
AES_256_HSM: SymmetricAlgorithm.ValueType  # 4
"""AES algorithm with 256-bit keys hosted by HSM"""
global___SymmetricAlgorithm = SymmetricAlgorithm

@typing.final
class SymmetricKey(google.protobuf.message.Message):
    """A symmetric KMS key that may contain several versions of the cryptographic material."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SymmetricKey._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: SymmetricKey._Status.ValueType  # 0
        CREATING: SymmetricKey._Status.ValueType  # 1
        """The key is being created."""
        ACTIVE: SymmetricKey._Status.ValueType  # 2
        """The key is active and can be used for encryption and decryption.
        Can be set to INACTIVE using the [SymmetricKeyService.Update] method.
        """
        INACTIVE: SymmetricKey._Status.ValueType  # 3
        """The key is inactive and unusable.
        Can be set to ACTIVE using the [SymmetricKeyService.Update] method.
        """

    class Status(_Status, metaclass=_StatusEnumTypeWrapper): ...
    STATUS_UNSPECIFIED: SymmetricKey.Status.ValueType  # 0
    CREATING: SymmetricKey.Status.ValueType  # 1
    """The key is being created."""
    ACTIVE: SymmetricKey.Status.ValueType  # 2
    """The key is active and can be used for encryption and decryption.
    Can be set to INACTIVE using the [SymmetricKeyService.Update] method.
    """
    INACTIVE: SymmetricKey.Status.ValueType  # 3
    """The key is inactive and unusable.
    Can be set to ACTIVE using the [SymmetricKeyService.Update] method.
    """

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    FOLDER_ID_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    PRIMARY_VERSION_FIELD_NUMBER: builtins.int
    DEFAULT_ALGORITHM_FIELD_NUMBER: builtins.int
    ROTATED_AT_FIELD_NUMBER: builtins.int
    ROTATION_PERIOD_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the key."""
    folder_id: builtins.str
    """ID of the folder that the key belongs to."""
    name: builtins.str
    """Name of the key."""
    description: builtins.str
    """Description of the key."""
    status: global___SymmetricKey.Status.ValueType
    """Current status of the key."""
    default_algorithm: global___SymmetricAlgorithm.ValueType
    """Default encryption algorithm to be used with new versions of the key."""
    deletion_protection: builtins.bool
    """Flag that inhibits deletion of the key"""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the key was created."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels for the key as `key:value` pairs. Maximum 64 per key."""

    @property
    def primary_version(self) -> global___SymmetricKeyVersion:
        """Primary version of the key, used as the default for all encrypt/decrypt operations,
        when no version ID is specified.
        """

    @property
    def rotated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of the last key rotation (time when the last version was created).
        Empty if the key does not have versions yet.
        """

    @property
    def rotation_period(self) -> google.protobuf.duration_pb2.Duration:
        """Time period between automatic key rotations."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        folder_id: builtins.str = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        name: builtins.str = ...,
        description: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        status: global___SymmetricKey.Status.ValueType = ...,
        primary_version: global___SymmetricKeyVersion | None = ...,
        default_algorithm: global___SymmetricAlgorithm.ValueType = ...,
        rotated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        rotation_period: google.protobuf.duration_pb2.Duration | None = ...,
        deletion_protection: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "primary_version", b"primary_version", "rotated_at", b"rotated_at", "rotation_period", b"rotation_period"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["created_at", b"created_at", "default_algorithm", b"default_algorithm", "deletion_protection", b"deletion_protection", "description", b"description", "folder_id", b"folder_id", "id", b"id", "labels", b"labels", "name", b"name", "primary_version", b"primary_version", "rotated_at", b"rotated_at", "rotation_period", b"rotation_period", "status", b"status"]) -> None: ...

global___SymmetricKey = SymmetricKey

@typing.final
class SymmetricKeyVersion(google.protobuf.message.Message):
    """Symmetric KMS key version: metadata about actual cryptographic data."""

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _Status:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _StatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[SymmetricKeyVersion._Status.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        STATUS_UNSPECIFIED: SymmetricKeyVersion._Status.ValueType  # 0
        ACTIVE: SymmetricKeyVersion._Status.ValueType  # 1
        """The version is active and can be used for encryption and decryption."""
        SCHEDULED_FOR_DESTRUCTION: SymmetricKeyVersion._Status.ValueType  # 2
        """The version is scheduled for destruction, the time when it will be destroyed
        is specified in the [SymmetricKeyVersion.destroy_at] field.
        """
        DESTROYED: SymmetricKeyVersion._Status.ValueType  # 3
        """The version is destroyed and cannot be recovered."""

    class Status(_Status, metaclass=_StatusEnumTypeWrapper):
        """Possible version status."""

    STATUS_UNSPECIFIED: SymmetricKeyVersion.Status.ValueType  # 0
    ACTIVE: SymmetricKeyVersion.Status.ValueType  # 1
    """The version is active and can be used for encryption and decryption."""
    SCHEDULED_FOR_DESTRUCTION: SymmetricKeyVersion.Status.ValueType  # 2
    """The version is scheduled for destruction, the time when it will be destroyed
    is specified in the [SymmetricKeyVersion.destroy_at] field.
    """
    DESTROYED: SymmetricKeyVersion.Status.ValueType  # 3
    """The version is destroyed and cannot be recovered."""

    ID_FIELD_NUMBER: builtins.int
    KEY_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    PRIMARY_FIELD_NUMBER: builtins.int
    DESTROY_AT_FIELD_NUMBER: builtins.int
    HOSTED_BY_HSM_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the key version."""
    key_id: builtins.str
    """ID of the symmetric KMS key that the version belongs to."""
    status: global___SymmetricKeyVersion.Status.ValueType
    """Status of the key version."""
    algorithm: global___SymmetricAlgorithm.ValueType
    """Encryption algorithm that should be used when using the key version to encrypt plaintext."""
    primary: builtins.bool
    """Indication of a primary version, that is to be used by default for all cryptographic
    operations that don't have a key version explicitly specified.
    """
    hosted_by_hsm: builtins.bool
    """Indication of the version that is hosted by HSM."""
    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the key version was created."""

    @property
    def destroy_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when the key version is going to be destroyed. Empty unless the status
        is `SCHEDULED_FOR_DESTRUCTION`.
        """

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        key_id: builtins.str = ...,
        status: global___SymmetricKeyVersion.Status.ValueType = ...,
        algorithm: global___SymmetricAlgorithm.ValueType = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        primary: builtins.bool = ...,
        destroy_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        hosted_by_hsm: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["created_at", b"created_at", "destroy_at", b"destroy_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["algorithm", b"algorithm", "created_at", b"created_at", "destroy_at", b"destroy_at", "hosted_by_hsm", b"hosted_by_hsm", "id", b"id", "key_id", b"key_id", "primary", b"primary", "status", b"status"]) -> None: ...

global___SymmetricKeyVersion = SymmetricKeyVersion



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: yandex/cloud/loadtesting/api/v1/report/kpi.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from yandex.cloud.loadtesting.api.v1.common import quantiles_pb2 as yandex_dot_cloud_dot_loadtesting_dot_api_dot_v1_dot_common_dot_quantiles__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0yandex/cloud/loadtesting/api/v1/report/kpi.proto\x12&yandex.cloud.loadtesting.api.v1.report\x1a\x36yandex/cloud/loadtesting/api/v1/common/quantiles.proto\"\x95\x01\n\x03Kpi\x12\x45\n\x08selector\x18\x01 \x01(\x0b\x32\x33.yandex.cloud.loadtesting.api.v1.report.KpiSelector\x12G\n\tthreshold\x18\x02 \x01(\x0b\x32\x34.yandex.cloud.loadtesting.api.v1.report.KpiThreshold\"e\n\x0cKpiThreshold\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x46\n\ncomparison\x18\x02 \x01(\x0e\x32\x32.yandex.cloud.loadtesting.api.v1.report.Comparison\"\xcc\x08\n\x0bKpiSelector\x12Y\n\rresponse_time\x18\x01 \x01(\x0b\x32@.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ResponseTimeH\x00\x12R\n\tinstances\x18\x02 \x01(\x0b\x32=.yandex.cloud.loadtesting.api.v1.report.KpiSelector.InstancesH\x00\x12Y\n\rimbalance_rps\x18\x03 \x01(\x0b\x32@.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ImbalanceRpsH\x00\x12l\n\x17protocol_codes_absolute\x18\x04 \x01(\x0b\x32I.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ProtocolCodesAbsoluteH\x00\x12l\n\x17protocol_codes_relative\x18\x05 \x01(\x0b\x32I.yandex.cloud.loadtesting.api.v1.report.KpiSelector.ProtocolCodesRelativeH\x00\x12j\n\x16network_codes_absolute\x18\x06 \x01(\x0b\x32H.yandex.cloud.loadtesting.api.v1.report.KpiSelector.NetworkCodesAbsoluteH\x00\x12j\n\x16network_codes_relative\x18\x07 \x01(\x0b\x32H.yandex.cloud.loadtesting.api.v1.report.KpiSelector.NetworkCodesRelativeH\x00\x1aV\n\x0cResponseTime\x12\x46\n\x08quantile\x18\x01 \x01(\x0e\x32\x34.yandex.cloud.loadtesting.api.v1.common.QuantileType\x1aM\n\tInstances\x12@\n\x03\x61gg\x18\x01 \x01(\x0e\x32\x33.yandex.cloud.loadtesting.api.v1.report.Aggregation\x1a\x0e\n\x0cImbalanceRps\x1a/\n\x15ProtocolCodesAbsolute\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\t\x1a/\n\x15ProtocolCodesRelative\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\t\x1a.\n\x14NetworkCodesAbsolute\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\t\x1a.\n\x14NetworkCodesRelative\x12\x16\n\x0e\x63odes_patterns\x18\x01 \x03(\tB\x06\n\x04kind*\x9a\x01\n\x0b\x41ggregation\x12\x1b\n\x17\x41GGREGATION_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x41GGREGATION_MIN\x10\x01\x12\x13\n\x0f\x41GGREGATION_MAX\x10\x02\x12\x13\n\x0f\x41GGREGATION_AVG\x10\x04\x12\x16\n\x12\x41GGREGATION_MEDIAN\x10\x05\x12\x17\n\x13\x41GGREGATION_STD_DEV\x10\x06*v\n\nComparison\x12\x1a\n\x16\x43OMPARISON_UNSPECIFIED\x10\x00\x12\x11\n\rCOMPARISON_LT\x10\x01\x12\x12\n\x0e\x43OMPARISON_LTE\x10\x02\x12\x11\n\rCOMPARISON_GT\x10\x03\x12\x12\n\x0e\x43OMPARISON_GTE\x10\x04\x42\x7f\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;reportb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'yandex.cloud.loadtesting.api.v1.report.kpi_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n*yandex.cloud.api.loadtesting.api.v1.reportZQgithub.com/yandex-cloud/go-genproto/yandex/cloud/loadtesting/api/v1/report;report'
  _globals['_AGGREGATION']._serialized_start=1507
  _globals['_AGGREGATION']._serialized_end=1661
  _globals['_COMPARISON']._serialized_start=1663
  _globals['_COMPARISON']._serialized_end=1781
  _globals['_KPI']._serialized_start=149
  _globals['_KPI']._serialized_end=298
  _globals['_KPITHRESHOLD']._serialized_start=300
  _globals['_KPITHRESHOLD']._serialized_end=401
  _globals['_KPISELECTOR']._serialized_start=404
  _globals['_KPISELECTOR']._serialized_end=1504
  _globals['_KPISELECTOR_RESPONSETIME']._serialized_start=1121
  _globals['_KPISELECTOR_RESPONSETIME']._serialized_end=1207
  _globals['_KPISELECTOR_INSTANCES']._serialized_start=1209
  _globals['_KPISELECTOR_INSTANCES']._serialized_end=1286
  _globals['_KPISELECTOR_IMBALANCERPS']._serialized_start=1288
  _globals['_KPISELECTOR_IMBALANCERPS']._serialized_end=1302
  _globals['_KPISELECTOR_PROTOCOLCODESABSOLUTE']._serialized_start=1304
  _globals['_KPISELECTOR_PROTOCOLCODESABSOLUTE']._serialized_end=1351
  _globals['_KPISELECTOR_PROTOCOLCODESRELATIVE']._serialized_start=1353
  _globals['_KPISELECTOR_PROTOCOLCODESRELATIVE']._serialized_end=1400
  _globals['_KPISELECTOR_NETWORKCODESABSOLUTE']._serialized_start=1402
  _globals['_KPISELECTOR_NETWORKCODESABSOLUTE']._serialized_end=1448
  _globals['_KPISELECTOR_NETWORKCODESRELATIVE']._serialized_start=1450
  _globals['_KPISELECTOR_NETWORKCODESRELATIVE']._serialized_end=1496
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.duration_pb2
import google.protobuf.internal.containers
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import google.protobuf.timestamp_pb2
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class Video(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    class _VideoStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VideoStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Video._VideoStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VIDEO_STATUS_UNSPECIFIED: Video._VideoStatus.ValueType  # 0
        """Video status unspecified."""
        WAIT_UPLOADING: Video._VideoStatus.ValueType  # 1
        """Waiting for the whole number of bytes to be loaded."""
        PROCESSING: Video._VideoStatus.ValueType  # 4
        """Video processing."""
        READY: Video._VideoStatus.ValueType  # 5
        """Video is ready, processing is completed."""
        ERROR: Video._VideoStatus.ValueType  # 7
        """An error occurred during video processing."""

    class VideoStatus(_VideoStatus, metaclass=_VideoStatusEnumTypeWrapper): ...
    VIDEO_STATUS_UNSPECIFIED: Video.VideoStatus.ValueType  # 0
    """Video status unspecified."""
    WAIT_UPLOADING: Video.VideoStatus.ValueType  # 1
    """Waiting for the whole number of bytes to be loaded."""
    PROCESSING: Video.VideoStatus.ValueType  # 4
    """Video processing."""
    READY: Video.VideoStatus.ValueType  # 5
    """Video is ready, processing is completed."""
    ERROR: Video.VideoStatus.ValueType  # 7
    """An error occurred during video processing."""

    class _VisibilityStatus:
        ValueType = typing.NewType("ValueType", builtins.int)
        V: typing_extensions.TypeAlias = ValueType

    class _VisibilityStatusEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[Video._VisibilityStatus.ValueType], builtins.type):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
        VISIBILITY_STATUS_UNSPECIFIED: Video._VisibilityStatus.ValueType  # 0
        """Visibility status unspecified."""
        PUBLISHED: Video._VisibilityStatus.ValueType  # 1
        """Video is published and available for viewing."""
        UNPUBLISHED: Video._VisibilityStatus.ValueType  # 2
        """Video is unpublished, only admin can watch."""

    class VisibilityStatus(_VisibilityStatus, metaclass=_VisibilityStatusEnumTypeWrapper): ...
    VISIBILITY_STATUS_UNSPECIFIED: Video.VisibilityStatus.ValueType  # 0
    """Visibility status unspecified."""
    PUBLISHED: Video.VisibilityStatus.ValueType  # 1
    """Video is published and available for viewing."""
    UNPUBLISHED: Video.VisibilityStatus.ValueType  # 2
    """Video is unpublished, only admin can watch."""

    @typing.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    CHANNEL_ID_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    THUMBNAIL_ID_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    DURATION_FIELD_NUMBER: builtins.int
    VISIBILITY_STATUS_FIELD_NUMBER: builtins.int
    TUSD_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    AUTH_SYSTEM_ACCESS_FIELD_NUMBER: builtins.int
    CREATED_AT_FIELD_NUMBER: builtins.int
    UPDATED_AT_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    id: builtins.str
    """ID of the video."""
    channel_id: builtins.str
    """ID of the channel where the video was created."""
    title: builtins.str
    """Video title."""
    description: builtins.str
    """Video description."""
    thumbnail_id: builtins.str
    """ID of the thumbnail."""
    status: global___Video.VideoStatus.ValueType
    """Video status."""
    visibility_status: global___Video.VisibilityStatus.ValueType
    """Video visibility status."""
    @property
    def duration(self) -> google.protobuf.duration_pb2.Duration:
        """Video duration. Optional, may be empty until the transcoding result is ready."""

    @property
    def tusd(self) -> global___VideoTUSDSource:
        """Upload video using the tus protocol."""

    @property
    def public_access(self) -> global___VideoPublicAccessRights:
        """Video is available to everyone."""

    @property
    def auth_system_access(self) -> global___VideoAuthSystemAccessRights:
        """Checking access rights using the authorization system."""

    @property
    def created_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time when video was created."""

    @property
    def updated_at(self) -> google.protobuf.timestamp_pb2.Timestamp:
        """Time of last video update."""

    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]:
        """Custom labels as `` key:value `` pairs. Maximum 64 per resource."""

    def __init__(
        self,
        *,
        id: builtins.str = ...,
        channel_id: builtins.str = ...,
        title: builtins.str = ...,
        description: builtins.str = ...,
        thumbnail_id: builtins.str = ...,
        status: global___Video.VideoStatus.ValueType = ...,
        duration: google.protobuf.duration_pb2.Duration | None = ...,
        visibility_status: global___Video.VisibilityStatus.ValueType = ...,
        tusd: global___VideoTUSDSource | None = ...,
        public_access: global___VideoPublicAccessRights | None = ...,
        auth_system_access: global___VideoAuthSystemAccessRights | None = ...,
        created_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        updated_at: google.protobuf.timestamp_pb2.Timestamp | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing.Literal["access_rights", b"access_rights", "auth_system_access", b"auth_system_access", "created_at", b"created_at", "duration", b"duration", "public_access", b"public_access", "source", b"source", "tusd", b"tusd", "updated_at", b"updated_at"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing.Literal["access_rights", b"access_rights", "auth_system_access", b"auth_system_access", "channel_id", b"channel_id", "created_at", b"created_at", "description", b"description", "duration", b"duration", "id", b"id", "labels", b"labels", "public_access", b"public_access", "source", b"source", "status", b"status", "thumbnail_id", b"thumbnail_id", "title", b"title", "tusd", b"tusd", "updated_at", b"updated_at", "visibility_status", b"visibility_status"]) -> None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["access_rights", b"access_rights"]) -> typing.Literal["public_access", "auth_system_access"] | None: ...
    @typing.overload
    def WhichOneof(self, oneof_group: typing.Literal["source", b"source"]) -> typing.Literal["tusd"] | None: ...

global___Video = Video

@typing.final
class VideoTUSDSource(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    URL_FIELD_NUMBER: builtins.int
    url: builtins.str
    """URL for uploading video via the tus protocol."""
    def __init__(
        self,
        *,
        url: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["url", b"url"]) -> None: ...

global___VideoTUSDSource = VideoTUSDSource

@typing.final
class VideoPublicAccessRights(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoPublicAccessRights = VideoPublicAccessRights

@typing.final
class VideoAuthSystemAccessRights(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    def __init__(
        self,
    ) -> None: ...

global___VideoAuthSystemAccessRights = VideoAuthSystemAccessRights



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""

import builtins
import google.protobuf.descriptor
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing.final
class TranslatedText(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TEXT_FIELD_NUMBER: builtins.int
    DETECTED_LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    text: builtins.str
    """Translated text."""
    detected_language_code: builtins.str
    """The language code of the source text.
    Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` en ``).
    """
    def __init__(
        self,
        *,
        text: builtins.str = ...,
        detected_language_code: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["detected_language_code", b"detected_language_code", "text", b"text"]) -> None: ...

global___TranslatedText = TranslatedText

@typing.final
class Language(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CODE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    code: builtins.str
    """The language code.
    Specified in [ISO 639-1](https://en.wikipedia.org/wiki/ISO_639-1) format (for example, `` en ``).
    """
    name: builtins.str
    """The name of the language (for example, `` English ``)."""
    def __init__(
        self,
        *,
        code: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing.Literal["code", b"code", "name", b"name"]) -> None: ...

global___Language = Language
